summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDave Airlie <airlied@redhat.com>2020-07-06 07:00:50 +1000
committerDave Airlie <airlied@redhat.com>2020-07-10 06:17:44 +1000
commitea47af87f692b291a988834c6f14d73a08cb1d75 (patch)
tree59de9a428349deb2f920d94048eb11e7ab6633ee /include
parent15b7738389b36ec2739d4f599539bcb7c2be89a1 (diff)
xserver/output: rename some badly named variables/APIs.
This is an API and ABI break Reviewed-by: Peter Hutterer <peter.hutterer@who-t.net>
Diffstat (limited to 'include')
-rw-r--r--include/pixmap.h4
-rw-r--r--include/pixmapstr.h4
-rw-r--r--include/scrnintstr.h26
3 files changed, 17 insertions, 17 deletions
diff --git a/include/pixmap.h b/include/pixmap.h
index f79c41549..7144bfb30 100644
--- a/include/pixmap.h
+++ b/include/pixmap.h
@@ -113,10 +113,10 @@ extern _X_EXPORT PixmapPtr AllocatePixmap(ScreenPtr /*pScreen */ ,
extern _X_EXPORT void FreePixmap(PixmapPtr /*pPixmap */ );
extern _X_EXPORT PixmapPtr
-PixmapShareToSlave(PixmapPtr pixmap, ScreenPtr slave);
+PixmapShareToSecondary(PixmapPtr pixmap, ScreenPtr secondary);
extern _X_EXPORT void
-PixmapUnshareSlavePixmap(PixmapPtr slave_pixmap);
+PixmapUnshareSecondaryPixmap(PixmapPtr secondary_pixmap);
#define HAS_DIRTYTRACKING_ROTATION 1
#define HAS_DIRTYTRACKING_DRAWABLE_SRC 1
diff --git a/include/pixmapstr.h b/include/pixmapstr.h
index de501013a..faf54fa4d 100644
--- a/include/pixmapstr.h
+++ b/include/pixmapstr.h
@@ -84,12 +84,12 @@ typedef struct _Pixmap {
#endif
unsigned usage_hint; /* see CREATE_PIXMAP_USAGE_* */
- PixmapPtr master_pixmap; /* pointer to master copy of pixmap for pixmap sharing */
+ PixmapPtr primary_pixmap; /* pointer to primary copy of pixmap for pixmap sharing */
} PixmapRec;
typedef struct _PixmapDirtyUpdate {
DrawablePtr src; /* Root window / shared pixmap */
- PixmapPtr slave_dst; /* Shared / scanout pixmap */
+ PixmapPtr secondary_dst; /* Shared / scanout pixmap */
int x, y;
DamagePtr damage;
struct xorg_list ent;
diff --git a/include/scrnintstr.h b/include/scrnintstr.h
index d2c65dc47..24ca423f2 100644
--- a/include/scrnintstr.h
+++ b/include/scrnintstr.h
@@ -362,17 +362,17 @@ typedef Bool (*SetSharedPixmapBackingProcPtr)(PixmapPtr, void *);
#define HAS_SYNC_SHARED_PIXMAP 1
/* The SyncSharedPixmap hook has two purposes:
*
- * 1. If the master driver has it, the slave driver can use it to
+ * 1. If the primary driver has it, the secondary driver can use it to
* synchronize the shared pixmap contents with the screen pixmap.
* 2. If the slave driver has it, the master driver can expect the slave
* driver to call the master screen's SyncSharedPixmap hook, so the master
* driver doesn't have to synchronize the shared pixmap contents itself,
* e.g. from the BlockHandler.
*
* A driver must only set the hook if it handles both cases correctly.
*
* The argument is the slave screen's pixmap_dirty_list entry, the hook is
* responsible for finding the corresponding entry in the master screen's
* pixmap_dirty_list.
*/
typedef void (*SyncSharedPixmapProcPtr)(PixmapDirtyUpdatePtr);
@@ -634,14 +634,14 @@ typedef struct _Screen {
Bool isGPU;
- /* Info on this screen's slaves (if any) */
- struct xorg_list slave_list;
- struct xorg_list slave_head;
- int output_slaves;
- /* Info for when this screen is a slave */
- ScreenPtr current_master;
- Bool is_output_slave;
- Bool is_offload_slave;
+ /* Info on this screen's secondarys (if any) */
+ struct xorg_list secondary_list;
+ struct xorg_list secondary_head;
+ int output_secondarys;
+ /* Info for when this screen is a secondary */
+ ScreenPtr current_primary;
+ Bool is_output_secondary;
+ Bool is_offload_secondary;
SharePixmapBackingProcPtr SharePixmapBacking;
SetSharedPixmapBackingProcPtr SetSharedPixmapBacking;
@@ -362,17 +362,17 @@ typedef Bool (*SetSharedPixmapBackingProcPtr)(PixmapPtr, void *);
* synchronize the shared pixmap contents with the screen pixmap.
- * 2. If the slave driver has it, the master driver can expect the slave
- * driver to call the master screen's SyncSharedPixmap hook, so the master
+ * 2. If the secondary driver has it, the primary driver can expect the secondary
+ * driver to call the primary screen's SyncSharedPixmap hook, so the primary
* driver doesn't have to synchronize the shared pixmap contents itself,
* e.g. from the BlockHandler.
@@ -362,17 +362,17 @@ typedef Bool (*SetSharedPixmapBackingProcPtr)(PixmapPtr, void *);
* A driver must only set the hook if it handles both cases correctly.
*
- * The argument is the slave screen's pixmap_dirty_list entry, the hook is
- * responsible for finding the corresponding entry in the master screen's
+ * The argument is the secondary screen's pixmap_dirty_list entry, the hook is
+ * responsible for finding the corresponding entry in the primary screen's
* pixmap_dirty_list.
*/